The source code

    /*!
     * Ext JS Library 3.3.1
     * Copyright(c) 2006-2010 Sencha Inc.
     * licensing@sencha.com
     * http://www.sencha.com/license
     */
    /**
     * @class Ext.ux.tree.TreeGridLoader
     * @extends Ext.tree.TreeLoader
     */
    Ext.ux.tree.TreeGridLoader = Ext.extend(Ext.tree.TreeLoader, {
        createNode : function(attr) {
            if (!attr.uiProvider) {
                attr.uiProvider = Ext.ux.tree.TreeGridNodeUI;
            }
            return Ext.tree.TreeLoader.prototype.createNode.call(this, attr);
        }
    });